-- =============================================
-- SaveToDB Framework for PostgreSQL
-- Version 7.19, March 12, 2018
--
-- This script copies settings from SaveToDB Framework 5-7 to SaveToDB Framework 8.
-- SaveToDB Framework 8 must be installed.
-- You may remove SaveToDB Framework 5-7 manually after successful copying.
--
-- Copyright 2018 Gartle Technology Corporation
-- =============================================

SET NOCOUNT ON

-- print Copying table data:

-- print savetodb_dev.query_list         -> xls.objects

INSERT INTO xls.objects
    ( table_schema
    , table_name
    , table_type
    , table_code
    , insert_object
    , update_object
    , delete_object
    )
SELECT
    s.table_schema
    , s.table_name
    , s.table_type
    , s.table_code
    , s.insert_procedure
    , s.update_procedure
    , s.delete_procedure
FROM
    savetodb_dev.query_list s
    LEFT OUTER JOIN xls.objects t ON t.table_schema = s.table_schema AND t.table_name = s.table_name
WHERE
    NOT s.table_schema IN ('savetodb_dev', 'savetodb_xls', 'savetodb_etl', 'http01')
    AND t.ID IS NULL;

-- print savetodb_dev.event_handlers     -> xls.handlers

INSERT INTO xls.handlers
    ( table_schema
    , table_name
    , column_name
    , event_name
    , handler_schema
    , handler_name
    , handler_type
    , handler_code
    , target_worksheet
    , menu_order
    , edit_parameters
    )
SELECT
    s.table_schema
    , s.table_name
    , s.column_name
    , s.event_name
    , s.handler_schema
    , s.handler_name
    , s.handler_type
    , s.handler_code
    , s.target_worksheet
    , s.menu_order
    , s.edit_parameters
FROM
    savetodb_dev.event_handlers s
    LEFT OUTER JOIN xls.handlers t ON t.table_schema = s.table_schema AND t.table_name = s.table_name
        AND COALESCE(t.column_name, '')     = COALESCE(s.column_name, '')
        AND COALESCE(t.handler_schema, '')  = COALESCE(s.handler_schema, '')
        AND COALESCE(t.handler_name, '')    = COALESCE(s.handler_name, '')
        AND COALESCE(t.handler_type, '')    = COALESCE(s.handler_type, '')
        AND COALESCE(t.menu_order, 0)       = COALESCE(s.menu_order, 0)
WHERE
    NOT s.table_schema IN ('savetodb_dev', 'savetodb_xls', 'savetodb_etl', 'http01')
    AND t.ID IS NULL;

-- print savetodb_dev.parameter_values   -> xls.handlers

INSERT INTO xls.handlers
    ( table_schema
    , table_name
    , column_name
    , event_name
    , handler_schema
    , handler_name
    , handler_type
    , handler_code
    , target_worksheet
    , menu_order
    , edit_parameters
    )
SELECT
    s.table_schema
    , s.table_name
    , s.parameter_name  AS column_name
    , 'ParameterValues' AS event_name
    , s.select_schema   AS handler_schema
    , s.select_name     AS handler_name
    , s.select_type     AS handler_type
    , s.select_code     AS handler_code
    , NULL              AS target_worksheet
    , NULL              AS menu_order
    , NULL              AS edit_parameters
FROM
    savetodb_dev.parameter_values s
    LEFT OUTER JOIN xls.handlers t ON t.table_schema = s.table_schema AND t.table_name = s.table_name
        AND COALESCE(s.parameter_name, '')  = COALESCE(t.column_name, '')
        AND COALESCE(s.select_schema, '')   = COALESCE(t.handler_schema, '')
        AND COALESCE(s.select_name, '')     = COALESCE(t.handler_name, '')
        AND COALESCE(s.select_type, '')     = COALESCE(t.handler_type, '')
WHERE
    NOT s.table_schema IN ('savetodb_dev', 'savetodb_xls', 'savetodb_etl', 'http01')
    AND t.ID IS NULL;

-- print savetodb_dev.object_translation -> xls.translations

INSERT INTO xls.translations
    ( table_schema
    , table_name
    , column_name
    , language_name
    , translated_name
    , translated_desc
    , translated_comment
    )
SELECT
    s.table_schema
    , s.table_name
    , NULL AS column_name
    , s.language_name
    , s.translated_name
    , s.translated_desc
    , s.translated_comment
FROM
    savetodb_dev.object_translation s
    LEFT OUTER JOIN xls.translations t ON t.table_schema = s.table_schema AND t.table_name = s.table_name
        AND t.language_name = s.language_name AND t.column_name IS NULL
WHERE
    NOT s.table_schema IN ('savetodb_dev', 'savetodb_xls', 'savetodb_etl', 'http01')
    AND t.ID IS NULL;

-- print savetodb_dev.column_translation -> xls.translations

INSERT INTO xls.translations
    ( table_schema
    , table_name
    , column_name
    , language_name
    , translated_name
    , translated_desc
    , translated_comment
    )
SELECT
    s.table_schema
    , s.table_name
    , s.column_name
    , s.language_name
    , s.translated_name
    , s.translated_desc
    , NULL AS translated_comment
FROM
    savetodb_dev.column_translation s
    LEFT OUTER JOIN xls.translations t ON t.table_schema = s.table_schema AND t.table_name = s.table_name
        AND t.language_name = s.language_name AND t.column_name = s.column_name
WHERE
    NOT s.table_schema IN ('savetodb_dev', 'savetodb_xls', 'savetodb_etl', 'http01')
    AND t.ID IS NULL;

-- print savetodb_dev.table_formats      -> xls.formats

INSERT INTO xls.formats
    ( table_schema
    , table_name
    , table_excel_format_xml
    )
SELECT
    s.table_schema
    , s.table_name
    , s.table_excel_format_xml
FROM
    savetodb_dev.table_formats s
    LEFT OUTER JOIN xls.formats t ON t.table_schema = s.table_schema AND t.table_name = s.table_name
WHERE
    NOT s.table_schema IN ('savetodb_dev', 'savetodb_xls', 'savetodb_etl', 'http01')
    AND t.ID IS NULL;
